Installation — python-measurement 1.0 documentation

### Navigation

- index
- next |
- previous |
- python-measurement 1.0 documentation »

# Installation

You can either install from pip:

    pip install measurement

or checkout and install the source from the bitbucket repository:

    hg clone https://bitbucket.org/latestrevision/python-measurement
    cd python-measurement
    python setup.py install

or checkout and install the source from the github repository:

    git clone https://github.com/latestrevision/python-measurement.git
    cd python-measurement
    python setup.py install

### Navigation

- index
- next |
- previous |
- python-measurement 1.0 documentation »